﻿options missing=.;

data meat_consumption;
informat year monyy7.;
format year year.;
input year chicken beef pork;
cards;
jan1950 21  44  65
jan1955 21  56  62
jan1960 28  59  59
jan1965 33  70  52
jan1970 40  82  55
jan1975 39  85  43
jan1980 47  75  57
jan1985 52  77  51
jan1990 61  66  49
jan1995 69  65  51
jan2000 77  67  51
;
run;
 
data annotable;
length x1space $ 13 y1space $ 13 anchor $ 11;
set meat_consumption (where=(year='01jan2000'd)) end=_last_;
retain anchor 'left' y1space 'datavalue' x1space 'datapercent' width 40 
       widthunit 'pixel' function 'image' x1 102;
y1 = chicken;
image = "&outpath\chicken.jpg";
output;
y1 = beef;
image = "&outpath\cow.jpg";
output;
y1 = pork;
image = "&outpath\pig.jpg";
output;
if (_last_) then do;
chicken=.;
beef=.;
pork=.;
x1space = "graphpercent";
y1space = "graphpercent";
anchor = "bottomright";
x1 = 99;
y1 = 1;
width=90;
image = "&outpath\Logo.png";
output;
function = "text";
anchor = "bottomleft";
image=' ';
x1 = 1;
width=150;
textsize = 6;
label = "Source: USDA";
output;
end;
run;

ods html;
proc print data=annotable;
  title 'Annotate Dataset: work.annotable';
run;
 
title;
footnote;

ods html(id=danno) gpath="&outpath" (url=none) 
         path="&outpath" (url=none)
		 file="anno_graph.html";
ods listing gpath="&outpath" ;
ods graphics / reset=all imagename='MMA';
Title1 "U.S. Per Capita Meat Consumption";
title2 "1950-2000";
 
proc sgplot data=meat_consumption noautolegend sganno=work.annotable pad=(bottom=8%);
xaxis display=(nolabel) offsetmax=0.1;
yaxis label="Retail Cut Equivalent / Lb. per Person";
series x=year y=chicken / markers markerattrs=(symbol=circlefilled size=12px color=CXa5aace) 
       lineattrs=(thickness=10 color=CXa5aace) transparency=0;
scatter x=year y=chicken / markerattrs=(symbol=circlefilled size=10px color=white);
series x=year y=pork / markers markerattrs=(symbol=circlefilled  size=12px color=CX84b2b3)
       lineattrs=(thickness=10 color=CX84b2b3) transparency=0;
scatter x=year y=pork / markerattrs=(symbol=circlefilled size=10px color=white);
series x=year y=beef / markers markerattrs=(symbol=circlefilled  size=12px color=CXd69e94)
       lineattrs=(thickness=10 color=CXd69e94) transparency=0;
scatter x=year y=beef / markerattrs=(symbol=circlefilled size=10px color=white);
run;
ods html(id=danno) close;
